@@ -207,6 +207,12 @@ class Browser(Explorer):
                 file = File(file).write(arg)
         return file
 
+    def html(self, arg, **kwargs):
+        """ 将内容转为html展示 """
+        file = File(..., Dir.TEMP, suffix='.html').write(arg)
+        file = file.rename(get_etag(str(file)) + file.suffix, if_exists='replace')
+        self.__call__(arg, file, **kwargs)
+
     def __call__(self, arg, file=None, *, wait=True, clsmsg=True, to_html_args=None,
                  **kwargs):  # NOQA Browser的操作跟标准接口略有差异
         """ 该版本会把arg转存文件重设为文件名
